@@ -3,15 +3,15 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.0.4";
+our $VERSION = "0.01";
 use Carp qw(croak);
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
 our @EXPORT = qw(subtest before after);
 
-my $LEVEL  = 0;
-my $BEFORE = {};
-my $AFTER  = {};
+our $Level = 0;
+our $BEFORE = {};
+our $AFTER  = {};
 
 BEGIN {
     croak "Test::More::Hooks must be loaded after Test::More."
@@ -20,35 +20,25 @@ BEGIN {
 
 sub subtest {
     my ($name, $subtests) = @_;
-    $BEFORE->{$LEVEL}->() if 'CODE' eq ref $BEFORE->{$LEVEL};
-    $LEVEL += 1;
+    $BEFORE->{$Level}->() if 'CODE' eq ref $BEFORE->{$Level};
+    $Level += 1;
 
     my $tb = Test::More::Hooks->builder;
     my $result = $tb->subtest(@_);
-    _clean_hooks();
 
-    $LEVEL -= 1;
-    $AFTER->{$LEVEL}->() if 'CODE' eq ref $AFTER->{$LEVEL};
+    $Level -= 1;
+    $AFTER->{$Level}->() if 'CODE' eq ref $AFTER->{$Level};
     return $result;
 }
 
 sub before (&) {
     my $block = shift;
-    $BEFORE->{$LEVEL} = $block;
+    $BEFORE->{$Level} = $block;
 }
 
 sub after (&) {
     my $block = shift;
-    $AFTER->{$LEVEL} = $block;
-}
-
-sub level {
-    return $LEVEL;
-}
-
-sub _clean_hooks {
-    $BEFORE->{$LEVEL} = undef;
-    $AFTER->{$LEVEL}  = undef;
+    $AFTER->{$Level} = $block;
 }
 
 1;
